==> jc-1.4.0.tar.gz: java/awt/Container__24AccessibleAWTContainer.h <==
// public class java.awt.Container$AccessibleAWTContainer

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Component__24AccessibleAWTComponent

#include "java/awt/Component__24AccessibleAWTComponent.h"

#ifndef _JC_java_awt_Container__24AccessibleAWTContainer_H_
#define _JC_java_awt_Container__24AccessibleAWTContainer_H_

// Forward structure declarations
struct _jc_java_awt_Container$object;
struct _jc_java_awt_Point$object;
struct _jc_java_awt_event_ContainerListener$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_Accessible$object;

// Typedefs
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	_jc_java_awt_Container__24AccessibleAWTContainer$sub_refs;
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	_jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs;
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer$refs	_jc_java_awt_Container__24AccessibleAWTContainer$refs;
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer$nonrefs	_jc_java_awt_Container__24AccessibleAWTContainer$nonrefs;
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer$object	_jc_java_awt_Container__24AccessibleAWTContainer$object;

typedef struct _jc_java_awt_Container__24AccessibleAWTContainer$fields_struct	_jc_java_awt_Container__24AccessibleAWTContainer$fields_struct;
typedef const struct _jc_java_awt_Container__24AccessibleAWTContainer$vmethods	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods;
typedef const struct _jc_java_awt_Container__24AccessibleAWTContainer$vtable	_jc_java_awt_Container__24AccessibleAWTContainer$vtable;
typedef const struct _jc_java_awt_Container__24AccessibleAWTContainer$vtype	_jc_java_awt_Container__24AccessibleAWTContainer$vtype;

// Class fields structure
struct _jc_java_awt_Container__24AccessibleAWTContainer$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_Container__24AccessibleAWTContainer$fields_struct _jc_java_awt_Container__24AccessibleAWTContainer$class_fields;

// Constructors
extern void _jc_java_awt_Container__24AccessibleAWTContainer$method$_init$a6b38a8e4e977d83(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *, struct _jc_java_awt_Container$object *);

// Virtual methods
extern struct _jc_object *_jc_java_awt_Container__24AccessibleAWTContainer$method$getAccessibleAt$f82d44e7e672d0d7(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *, struct _jc_java_awt_Point$object *);
extern struct _jc_object *_jc_java_awt_Container__24AccessibleAWTContainer$method$getAccessibleChild$98cf334feace704a(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *, jint);
extern jint _jc_java_awt_Container__24AccessibleAWTContainer$method$getAccessibleChildrenCount$01361302630f8ed1(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *);
extern void _jc_java_awt_Container__24AccessibleAWTContainer$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Container__24AccessibleAWTContainer$method_info$getAccessibleAt$f82d44e7e672d0d7;
extern _jc_method _jc_java_awt_Container__24AccessibleAWTContainer$method_info$getAccessibleChild$98cf334feace704a;
extern _jc_method _jc_java_awt_Container__24AccessibleAWTContainer$method_info$getAccessibleChildrenCount$01361302630f8ed1;
extern _jc_method _jc_java_awt_Container__24AccessibleAWTContainer$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_awt_Container__24AccessibleAWTContainer$vmethods {
	struct _jc_object	*(*getAccessibleAt$f82d44e7e672d0d7)(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *, struct _jc_java_awt_Point$object *);
	struct _jc_object	*(*getAccessibleChild$98cf334feace704a)(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *, jint);
	jint	(*getAccessibleChildrenCount$01361302630f8ed1)(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *);
};

// Vtable
struct _jc_java_awt_Container__24AccessibleAWTContainer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
};

// Vtype
struct _jc_java_awt_Container__24AccessibleAWTContainer$vtype {
	_jc_type			type;
	_jc_java_awt_Container__24AccessibleAWTContainer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs {
	struct _jc_object	*accessibleContainerHandler;
	struct _jc_java_awt_Container$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Container__24AccessibleAWTContainer$refs {
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Container__24AccessibleAWTContainer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
};

// Object instance structure
struct _jc_java_awt_Container__24AccessibleAWTContainer$object {
	_jc_java_awt_Container__24AccessibleAWTContainer$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Container__24AccessibleAWTContainer$vtype	*vtype;
	_jc_java_awt_Container__24AccessibleAWTContainer$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Container__24AccessibleAWTContainer$vtype _jc_java_awt_Container__24AccessibleAWTContainer$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Container__24AccessibleAWTContainer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Container__24AccessibleAWTContainer$class_object;

#endif	/* _JC_java_awt_Container__24AccessibleAWTContainer_H_ */

==> jc-1.4.5.tar.gz: java/awt/Container__24AccessibleAWTContainer.h <==
// public class java.awt.Container$AccessibleAWTContainer

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Component__24AccessibleAWTComponent

#include "java/awt/Component__24AccessibleAWTComponent.h"

#ifndef _JC_java_awt_Container__24AccessibleAWTContainer_H_
#define _JC_java_awt_Container__24AccessibleAWTContainer_H_

// Forward structure declarations
struct _jc_java_awt_Container$object;
struct _jc_java_awt_Point$object;
struct _jc_java_awt_event_ContainerListener$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_Accessible$object;

// Typedefs
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	_jc_java_awt_Container__24AccessibleAWTContainer$sub_refs;
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	_jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs;
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer$refs	_jc_java_awt_Container__24AccessibleAWTContainer$refs;
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer$nonrefs	_jc_java_awt_Container__24AccessibleAWTContainer$nonrefs;
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer$object	_jc_java_awt_Container__24AccessibleAWTContainer$object;

typedef struct _jc_java_awt_Container__24AccessibleAWTContainer$fields_struct	_jc_java_awt_Container__24AccessibleAWTContainer$fields_struct;
typedef const struct _jc_java_awt_Container__24AccessibleAWTContainer$vmethods	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods;
typedef const struct _jc_java_awt_Container__24AccessibleAWTContainer$vtable	_jc_java_awt_Container__24AccessibleAWTContainer$vtable;
typedef const struct _jc_java_awt_Container__24AccessibleAWTContainer$vtype	_jc_java_awt_Container__24AccessibleAWTContainer$vtype;

// Class fields structure
struct _jc_java_awt_Container__24AccessibleAWTContainer$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_Container__24AccessibleAWTContainer$fields_struct _jc_java_awt_Container__24AccessibleAWTContainer$class_fields;

// Constructors
extern void _jc_java_awt_Container__24AccessibleAWTContainer$method$_init$a6b38a8e4e977d83(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_awt_Container__24AccessibleAWTContainer$method$getAccessibleAt$f82d44e7e672d0d7(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_awt_Container__24AccessibleAWTContainer$method$getAccessibleChild$98cf334feace704a(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_java_awt_Container__24AccessibleAWTContainer$method$getAccessibleChildrenCount$01361302630f8ed1(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_Container__24AccessibleAWTContainer$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Container__24AccessibleAWTContainer$method_info$getAccessibleAt$f82d44e7e672d0d7;
extern _jc_method _jc_java_awt_Container__24AccessibleAWTContainer$method_info$getAccessibleChild$98cf334feace704a;
extern _jc_method _jc_java_awt_Container__24AccessibleAWTContainer$method_info$getAccessibleChildrenCount$01361302630f8ed1;
extern _jc_method _jc_java_awt_Container__24AccessibleAWTContainer$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_awt_Container__24AccessibleAWTContainer$vmethods {
	struct _jc_object	*(*getAccessibleAt$f82d44e7e672d0d7)(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getAccessibleChild$98cf334feace704a)(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *, jint) _JC_JCNI_ATTR;
	jint	(*getAccessibleChildrenCount$01361302630f8ed1)(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Container__24AccessibleAWTContainer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
};

// Vtype
struct _jc_java_awt_Container__24AccessibleAWTContainer$vtype {
	_jc_type			type;
	_jc_java_awt_Container__24AccessibleAWTContainer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs {
	struct _jc_object	*accessibleContainerHandler;
	struct _jc_java_awt_Container$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Container__24AccessibleAWTContainer$refs {
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Container__24AccessibleAWTContainer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
};

// Object instance structure
struct _jc_java_awt_Container__24AccessibleAWTContainer$object {
	_jc_java_awt_Container__24AccessibleAWTContainer$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Container__24AccessibleAWTContainer$vtype	*vtype;
	_jc_java_awt_Container__24AccessibleAWTContainer$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Container__24AccessibleAWTContainer$vtype _jc_java_awt_Container__24AccessibleAWTContainer$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Container__24AccessibleAWTContainer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Container__24AccessibleAWTContainer$class_object;

#endif	/* _JC_java_awt_Container__24AccessibleAWTContainer_H_ */
